@@ -126,9 +126,7 @@ class XDiagnoseApplet(Gtk.Window):
                 break
 
         # Icons
-        icon_file = os.path.join(datadir, 'icons', 'microscope.svg')
-        pixbuf = Pixbuf.new_from_file(icon_file)
-        self.set_icon(pixbuf)
+        self.set_icon_name('xdiagnose')
 
     def destroy(self, widget=None, event=None, data=None):
         self.is_running = False
